@@ -44,7 +44,6 @@ class BulkHookManager(models.Manager):
         update_fields=None,
         unique_fields=None,
         bypass_hooks=False,
-        bypass_validation=False,
         **kwargs,
     ):
         """
@@ -61,7 +60,6 @@ class BulkHookManager(models.Manager):
             update_fields=update_fields,
             unique_fields=unique_fields,
             bypass_hooks=bypass_hooks,
-            bypass_validation=bypass_validation,
             **kwargs,
         )
 
@@ -70,7 +68,6 @@ class BulkHookManager(models.Manager):
         objs,
         fields=None,
         bypass_hooks=False,
-        bypass_validation=False,
         **kwargs,
     ):
         """
@@ -88,7 +85,6 @@ class BulkHookManager(models.Manager):
             "bulk_update",
             objs,
             bypass_hooks=bypass_hooks,
-            bypass_validation=bypass_validation,
             **kwargs,
         )
 
@@ -97,7 +93,6 @@ class BulkHookManager(models.Manager):
         objs,
         batch_size=None,
         bypass_hooks=False,
-        bypass_validation=False,
         **kwargs,
     ):
         """
@@ -110,31 +105,30 @@ class BulkHookManager(models.Manager):
             objs,
             batch_size=batch_size,
             bypass_hooks=bypass_hooks,
-            bypass_validation=bypass_validation,
             **kwargs,
         )
 
-    def delete(self):
+    def delete(self, bypass_hooks=False):
         """
         Delegate to QuerySet's delete implementation.
         This follows Django's pattern where Manager methods call QuerySet methods.
         """
-        return _delegate_to_queryset(self, "delete")
+        return _delegate_to_queryset(self, "delete", bypass_hooks=bypass_hooks)
 
-    def update(self, **kwargs):
+    def update(self, bypass_hooks=False, **kwargs):
         """
         Delegate to QuerySet's update implementation.
         This follows Django's pattern where Manager methods call QuerySet methods.
         """
-        return _delegate_to_queryset(self, "update", **kwargs)
+        return _delegate_to_queryset(self, "update", bypass_hooks=bypass_hooks, **kwargs)
 
-    def save(self, obj):
+    def save(self, obj, bypass_hooks=False):
         """
         Save a single object using the appropriate bulk operation.
         """
         if obj.pk:
             # bulk_update now auto-detects changed fields
-            self.bulk_update([obj])
+            self.bulk_update([obj], bypass_hooks=bypass_hooks)
         else:
-            self.bulk_create([obj])
+            self.bulk_create([obj], bypass_hooks=bypass_hooks)
         return obj
